# This file was first automatically generated by gen-acme-cpanmodules-module-from-acme-cpanlists-list on Sat Sep 22 06:13:03 2018 from module list in Acme::CPANLists::PERLANCAR::Self::CLIWithSubcommands version 0.003.

package Acme::CPANModules::PERLANCAR::MyCLIWithSubcommands;

use strict;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2023-11-01'; # DATE
our $DIST = 'Acme-CPANModulesBundle-PERLANCAR'; # DIST
our $VERSION = '0.013'; # VERSION

our $LIST = {
  entries => [
               { module => "App::AcmeCpanlists", scripts => ["acme-cpanlists"] },
               { module => "App::CPAN::Changes", scripts => ["cpan-changes"] },
               { module => "App::dux", scripts => ["dux"] },
               { module => "App::GitUtils", scripts => ["gu"] },
               { module => "App::lcpan", scripts => ["lcpan"] },
               { module => "App::pause", scripts => ["pause"] },
               { module => "App::PDRUtils", scripts => ["pdrutil", "pdrutil-multi"] },
               { module => "App::reposdb", scripts => ["reposdb"] },
               { module => "App::rimetadb", scripts => ["rimetadb"] },
               { module => "App::shcompgen", scripts => ["shcompgen"] },
               { module => "App::short", scripts => ["short"] },
               { module => "App::TableDataUtils", scripts => ["gen-rand-table"] },
               { module => "App::perlmv::u", scripts => ["perlmv-u"] },
               { module => "App::trash::u", scripts => ["trash-u"] },
               { module => "App::upf", scripts => ["upf"] },
               { module => "App::wp::xmlrpc", scripts => ["wp-xmlrpc"] },
               { module => "Git::Bunch", scripts => ["gitbunch"] },
               { module => "phpBB2::Simple", scripts => ["phpbb2"] },
             ],
  summary => "List of distributions that contain CLI scripts with subcommands",
};

1;
# ABSTRACT: Distributions that contain CLI scripts with subcommands

__END__

=pod

=encoding UTF-8

=head1 NAME

Acme::CPANModules::PERLANCAR::MyCLIWithSubcommands - Distributions that contain CLI scripts with subcommands

=head1 VERSION

This document describes version 0.013 of Acme::CPANModules::PERLANCAR::MyCLIWithSubcommands (from Perl distribution Acme-CPANModulesBundle-PERLANCAR), released on 2023-11-01.

=head1 ACME::CPANMODULES ENTRIES

=over

=item L<App::AcmeCpanlists>

Script: L<acme-cpanlists>

=item L<App::CPAN::Changes>

Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>

Script: L<cpan-changes>

=item L<App::dux>

Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>

Script: L<dux>

=item L<App::GitUtils>

Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>

Script: L<gu>

=item L<App::lcpan>

Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>

Script: L<lcpan>

=item L<App::pause>

Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>

Script: L<pause>

=item L<App::PDRUtils>

Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>

Scripts: L<pdrutil>, L<pdrutil-multi>

=item L<App::reposdb>

Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>

Script: L<reposdb>

=item L<App::rimetadb>

Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>

Script: L<rimetadb>

=item L<App::shcompgen>

Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>

Script: L<shcompgen>

=item L<App::short>

Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>

Script: L<short>

=item L<App::TableDataUtils>

Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>

Script: L<gen-rand-table>

=item L<App::perlmv::u>

Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>

Script: L<perlmv-u>

=item L<App::trash::u>

Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>

Script: L<trash-u>

=item L<App::upf>

Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>

Script: L<upf>

=item L<App::wp::xmlrpc>

Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>

Script: L<wp-xmlrpc>

=item L<Git::Bunch>

Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>

Script: L<gitbunch>

=item L<phpBB2::Simple>

Author: L<PERLANCAR|https://metacpan.org/author/PERLANCAR>

Script: L<phpbb2>

=back

=head1 FAQ

=head2 What is an Acme::CPANModules::* module?

An Acme::CPANModules::* module, like this module, contains just a list of module
names that share a common characteristics. It is a way to categorize modules and
document CPAN. See L<Acme::CPANModules> for more details.

=head2 What are ways to use this Acme::CPANModules module?

Aside from reading this Acme::CPANModules module's POD documentation, you can
install all the listed modules (entries) using L<cpanm-cpanmodules> script (from
L<App::cpanm::cpanmodules> distribution):

 % cpanm-cpanmodules -n PERLANCAR::MyCLIWithSubcommands

Alternatively you can use the L<cpanmodules> CLI (from L<App::cpanmodules>
distribution):

    % cpanmodules ls-entries PERLANCAR::MyCLIWithSubcommands | cpanm -n

or L<Acme::CM::Get>:

    % perl -MAcme::CM::Get=PERLANCAR::MyCLIWithSubcommands -E'say $_->{module} for @{ $LIST->{entries} }' | cpanm -n

or directly:

    % perl -MAcme::CPANModules::PERLANCAR::MyCLIWithSubcommands -E'say $_->{module} for @{ $Acme::CPANModules::PERLANCAR::MyCLIWithSubcommands::LIST->{entries} }' | cpanm -n

This Acme::CPANModules module also helps L<lcpan> produce a more meaningful
result for C<lcpan related-mods> command when it comes to finding related
modules for the modules listed in this Acme::CPANModules module.
See L<App::lcpan::Cmd::related_mods> for more details on how "related modules"
are found.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Acme-CPANModulesBundle-PERLANCAR>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Acme-CPANModulesBundle-PERLANCAR>.

=head1 SEE ALSO

L<Acme::CPANModules> - about the Acme::CPANModules namespace

L<cpanmodules> - CLI tool to let you browse/view the lists

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 CONTRIBUTING


To contribute, you can send patches by email/via RT, or send pull requests on
GitHub.

Most of the time, you don't need to build the distribution yourself. You can
simply modify the code, then test via:

 % prove -l

If you want to build the distribution (e.g. to try to install it locally on your
system), you can install L<Dist::Zilla>,
L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
that are considered a bug and can be reported to me.

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2023, 2021, 2020, 2019, 2018 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANModulesBundle-PERLANCAR>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=cut
